summaryrefslogtreecommitdiff
Side-by-side diff
Diffstat (more/less context) (ignore whitespace changes)
-rw-r--r--core/pim/addressbook/ablabel.cpp14
-rw-r--r--core/pim/addressbook/abtable.cpp46
-rw-r--r--core/pim/addressbook/abview.cpp52
-rw-r--r--core/pim/addressbook/addressbook.cpp58
-rw-r--r--core/pim/addressbook/configdlg.cpp10
-rw-r--r--core/pim/addressbook/contacteditor.cpp58
-rw-r--r--core/pim/addressbook/picker.cpp2
7 files changed, 120 insertions, 120 deletions
diff --git a/core/pim/addressbook/ablabel.cpp b/core/pim/addressbook/ablabel.cpp
index b81a3b9..6b8e4dd 100644
--- a/core/pim/addressbook/ablabel.cpp
+++ b/core/pim/addressbook/ablabel.cpp
@@ -97,7 +97,7 @@ void AbLabel::keyPressEvent( QKeyEvent *e )
case Qt::Key_Left:
- owarn << "Left.." << oendl;
+ odebug << "Left.." << oendl;
case Qt::Key_Right:
- owarn << "Right.." << oendl;
+ odebug << "Right.." << oendl;
case Qt::Key_F33:
- owarn << "OK.." << oendl;
+ odebug << "OK.." << oendl;
emit signalOkPressed();
@@ -105,3 +105,3 @@ void AbLabel::keyPressEvent( QKeyEvent *e )
case Qt::Key_Up:
- owarn << "Up.." << oendl;
+ odebug << "Up.." << oendl;
if ( ( visibleHeight() < contentsHeight() ) &&
@@ -119,5 +119,5 @@ void AbLabel::keyPressEvent( QKeyEvent *e )
case Qt::Key_Down:
- owarn << "Down.." << oendl;
-// owarn << "Visible: " << visibleHeight() << ", content: " << contentHeight() << oendl;
-// owarn << "Value: " << verticalScrollBar()->value()
+ odebug << "Down.." << oendl;
+// odebug << "Visible: " << visibleHeight() << ", content: " << contentHeight() << oendl;
+// odebug << "Value: " << verticalScrollBar()->value()
// << ", barMaxValue: " << verticalScrollBar()->maxValue() << oendl;
diff --git a/core/pim/addressbook/addressbook.cpp b/core/pim/addressbook/addressbook.cpp
index 35d0f41..835038a 100644
--- a/core/pim/addressbook/addressbook.cpp
+++ b/core/pim/addressbook/addressbook.cpp
@@ -269,6 +269,6 @@ void AddressbookWindow::slotConfig()
if ( QPEApplication::execDialog( dlg ) ) {
- owarn << "Config Dialog accepted!" << oendl;
+ odebug << "Config Dialog accepted!" << oendl;
m_config = dlg -> getConfig();
if ( m_curFontSize != m_config.fontSize() ){
- owarn << "Font was changed!" << oendl;
+ odebug << "Font was changed!" << oendl;
m_curFontSize = m_config.fontSize();
@@ -285,3 +285,3 @@ void AddressbookWindow::slotSetFont( int size )
{
- owarn << "void AddressbookWindow::slotSetFont( " << size << " )" << oendl;
+ odebug << "void AddressbookWindow::slotSetFont( " << size << " )" << oendl;
@@ -327,6 +327,6 @@ void AddressbookWindow::exportvCard()
{
- owarn << "void AddressbookWindow::exportvCard()" << oendl;
+ odebug << "void AddressbookWindow::exportvCard()" << oendl;
QString filename = Opie::Ui::OFileDialog::getSaveFileName( 1,"/home/"); //,"", "*", this );
if( !filename.isEmpty() && ( filename[filename.length()-1] != '/' ) ){
- owarn << " Save to file " << filename << ", (" << filename.length()-1 << ")" << oendl;
+ odebug << " Save to file " << filename << ", (" << filename.length()-1 << ")" << oendl;
Opie::OPimContact curCont = m_abView->currentEntry();
@@ -352,3 +352,3 @@ void AddressbookWindow::setDocument( const QString &filename )
{
- owarn << "void AddressbookWindow::setDocument( " << filename << " )" << oendl;
+ odebug << "void AddressbookWindow::setDocument( " << filename << " )" << oendl;
@@ -364,6 +364,6 @@ void AddressbookWindow::setDocument( const QString &filename )
case 0:
- owarn << "YES clicked" << oendl;
+ odebug << "YES clicked" << oendl;
break;
case 1:
- owarn << "NO clicked" << oendl;
+ odebug << "NO clicked" << oendl;
return;
@@ -377,3 +377,3 @@ void AddressbookWindow::setDocument( const QString &filename )
Opie::OPimContactAccess::List allList = access->allRecords();
- owarn << "Found number of contacts in File: " << allList.count() << oendl;
+ odebug << "Found number of contacts in File: " << allList.count() << oendl;
@@ -388,3 +388,3 @@ void AddressbookWindow::setDocument( const QString &filename )
for ( it = allList.begin(); it != allList.end(); ++it ){
- owarn << "Adding Contact from: " << (*it).fullName() << oendl;
+ odebug << "Adding Contact from: " << (*it).fullName() << oendl;
if ( doAsk ){
@@ -397,3 +397,3 @@ void AddressbookWindow::setDocument( const QString &filename )
case 0:
- owarn << "YES clicked" << oendl;
+ odebug << "YES clicked" << oendl;
m_abView->addEntry( *it );
@@ -401,6 +401,6 @@ void AddressbookWindow::setDocument( const QString &filename )
case 1:
- owarn << "NO clicked" << oendl;
+ odebug << "NO clicked" << oendl;
break;
case 2:
- owarn << "YesAll clicked" << oendl;
+ odebug << "YesAll clicked" << oendl;
doAsk = false;
@@ -540,5 +540,5 @@ void AddressbookWindow::writeMail()
if ( m_config.useQtMail() ){
- owarn << "Accessing: " << (basepath + "/bin/qtmail") << oendl;
+ odebug << "Accessing: " << (basepath + "/bin/qtmail") << oendl;
if ( QFile::exists( basepath + "/bin/qtmail" ) ){
- owarn << "QCop" << oendl;
+ odebug << "QCop" << oendl;
QCopEnvelope e("QPE/Application/qtmail", "writeMail(QString,QString)");
@@ -550,5 +550,5 @@ void AddressbookWindow::writeMail()
if ( m_config.useOpieMail() ){
- owarn << "Accessing: " << (basepath + "/bin/opiemail") << oendl;
+ odebug << "Accessing: " << (basepath + "/bin/opiemail") << oendl;
if ( QFile::exists( basepath + "/bin/opiemail" ) ){
- owarn << "QCop" << oendl;
+ odebug << "QCop" << oendl;
QCopEnvelope e("QPE/Application/opiemail", "writeMail(QString,QString)");
@@ -594,3 +594,3 @@ void AddressbookWindow::slotBeam()
- owarn << "Beaming: " << beamFilename << oendl;
+ odebug << "Beaming: " << beamFilename << oendl;
@@ -641,3 +641,3 @@ void AddressbookWindow::appMessage(const QCString &msg, const QByteArray &data)
bool needShow = FALSE;
- owarn << "Receiving QCop-Call with message " << msg << oendl;
+ odebug << "Receiving QCop-Call with message " << msg << oendl;
@@ -684,3 +684,3 @@ void AddressbookWindow::appMessage(const QCString &msg, const QByteArray &data)
- owarn << "Showing uid: " << uid << oendl;
+ odebug << "Showing uid: " << uid << oendl;
@@ -764,3 +764,3 @@ void AddressbookWindow::editPersonal()
if ( ! actionPersonal->isOn() ){
- owarn << "*** ++++" << oendl;
+ odebug << "*** ++++" << oendl;
actionPersonal->setOn( true );
@@ -783,6 +783,6 @@ void AddressbookWindow::slotPersonalView()
{
- owarn << "slotPersonalView()" << oendl;
+ odebug << "slotPersonalView()" << oendl;
if (!actionPersonal->isOn()) {
// we just turned it off
- owarn << "slotPersonalView()-> OFF" << oendl;
+ odebug << "slotPersonalView()-> OFF" << oendl;
setCaption( tr("Contacts") );
@@ -799,3 +799,3 @@ void AddressbookWindow::slotPersonalView()
- owarn << "slotPersonalView()-> ON" << oendl;
+ odebug << "slotPersonalView()-> ON" << oendl;
// XXX need to disable some QActions.
@@ -889,3 +889,3 @@ void AddressbookWindow::slotNotFound()
{
- owarn << "Got not found signal!" << oendl;
+ odebug << "Got not found signal!" << oendl;
QMessageBox::information( this, tr( "Not Found" ),
@@ -897,3 +897,3 @@ void AddressbookWindow::slotWrapAround()
{
- owarn << "Got wrap signal!" << oendl;
+ odebug << "Got wrap signal!" << oendl;
// if ( doNotifyWrapAround )
@@ -906,3 +906,3 @@ void AddressbookWindow::slotSetCategory( int c )
{
- owarn << "void AddressbookWindow::slotSetCategory( " << c << " ) from "
+ odebug << "void AddressbookWindow::slotSetCategory( " << c << " ) from "
<< catMenu->count() << oendl;
@@ -942,3 +942,3 @@ void AddressbookWindow::slotSetCategory( int c )
cat = "Unfiled";
- owarn << "Unfiled selected!" << oendl;
+ odebug << "Unfiled selected!" << oendl;
}else{
@@ -965,3 +965,3 @@ void AddressbookWindow::slotViewSwitched( int view )
{
- owarn << "void AddressbookWindow::slotViewSwitched( " << view << " )" << oendl;
+ odebug << "void AddressbookWindow::slotViewSwitched( " << view << " )" << oendl;
int menu = 0;
diff --git a/core/pim/addressbook/configdlg.cpp b/core/pim/addressbook/configdlg.cpp
index 22f7291..61e6c7e 100644
--- a/core/pim/addressbook/configdlg.cpp
+++ b/core/pim/addressbook/configdlg.cpp
@@ -45,3 +45,3 @@ void ConfigDlg::slotItemUp()
{
- owarn << "void ConfigDlg::slotItemUp()" << oendl;
+ odebug << "void ConfigDlg::slotItemUp()" << oendl;
@@ -59,3 +59,3 @@ void ConfigDlg::slotItemDown()
{
- owarn << "void ConfigDlg::slotItemDown()" << oendl;
+ odebug << "void ConfigDlg::slotItemDown()" << oendl;
@@ -72,3 +72,3 @@ void ConfigDlg::slotItemAdd()
{
- owarn << "void ConfigDlg::slotItemAdd()" << oendl;
+ odebug << "void ConfigDlg::slotItemAdd()" << oendl;
@@ -77,3 +77,3 @@ void ConfigDlg::slotItemAdd()
QString item = allFieldListBox->currentText();
- owarn << "Adding " << item << oendl;
+ odebug << "Adding " << item << oendl;
fieldListBox->insertItem( item );
@@ -84,3 +84,3 @@ void ConfigDlg::slotItemRemove()
{
- owarn << "void ConfigDlg::slotItemRemove()" << oendl;
+ odebug << "void ConfigDlg::slotItemRemove()" << oendl;
diff --git a/core/pim/addressbook/contacteditor.cpp b/core/pim/addressbook/contacteditor.cpp
index 312c663..b078968 100644
--- a/core/pim/addressbook/contacteditor.cpp
+++ b/core/pim/addressbook/contacteditor.cpp
@@ -81,3 +81,3 @@ ContactEditor::~ContactEditor() {
void ContactEditor::init() {
- owarn << "init() START" << oendl;
+ odebug << "init() START" << oendl;
@@ -690,3 +690,3 @@ void ContactEditor::init() {
- owarn << "init() END" << oendl;
+ odebug << "init() END" << oendl;
}
@@ -741,3 +741,3 @@ bool ContactEditor::cmbChooserChange( int index, QWidgetStack* inputStack, int w
QString type = slChooserNames[index];
- owarn << "ContactEditor::cmbChooserChange -> Type: " << type
+ odebug << "ContactEditor::cmbChooserChange -> Type: " << type
<< ", WidgetPos: " << widgetPos << oendl;
@@ -749,3 +749,3 @@ bool ContactEditor::cmbChooserChange( int index, QWidgetStack* inputStack, int w
if ( type == "Default Email"){
- owarn << "Choosing default-email (defaultEmailChooserPosition= "
+ odebug << "Choosing default-email (defaultEmailChooserPosition= "
<< defaultEmailChooserPosition << ") " << oendl;
@@ -783,3 +783,3 @@ bool ContactEditor::cmbChooserChange( int index, QWidgetStack* inputStack, int w
// Something else was selected: Hide combo..
- owarn << " Hiding default-email combo" << oendl;
+ odebug << " Hiding default-email combo" << oendl;
if ( defaultEmailChooserPosition == widgetPos ){
@@ -849,3 +849,3 @@ void ContactEditor::chooserChange( const QString &textChanged, int index,
if ( type == "Default Email"){
- owarn << "??? Wozu??: " << textChanged << oendl;
+ odebug << "??? Wozu??: " << textChanged << oendl;
defaultEmail = textChanged;
@@ -868,3 +868,3 @@ void ContactEditor::chooserChange( const QString &textChanged, int index,
void ContactEditor::slotChooser1Change( const QString &textChanged ) {
- owarn << "ContactEditor::slotChooser1Change( " << textChanged << " )" << oendl;
+ odebug << "ContactEditor::slotChooser1Change( " << textChanged << " )" << oendl;
chooserChange( textChanged, cmbChooserField1->currentItem(), txtChooserField1, 1);
@@ -873,3 +873,3 @@ void ContactEditor::slotChooser1Change( const QString &textChanged ) {
void ContactEditor::slotChooser2Change( const QString &textChanged ) {
- owarn << "ContactEditor::slotChooser2Change( " << textChanged << " )" << oendl;
+ odebug << "ContactEditor::slotChooser2Change( " << textChanged << " )" << oendl;
chooserChange( textChanged, cmbChooserField2->currentItem(), txtChooserField2, 2);
@@ -879,3 +879,3 @@ void ContactEditor::slotChooser2Change( const QString &textChanged ) {
void ContactEditor::slotChooser3Change( const QString &textChanged ) {
- owarn << "ContactEditor::slotChooser3Change( " << textChanged << " )" << oendl;
+ odebug << "ContactEditor::slotChooser3Change( " << textChanged << " )" << oendl;
chooserChange( textChanged, cmbChooserField3->currentItem(), txtChooserField3, 3);
@@ -884,3 +884,3 @@ void ContactEditor::slotChooser3Change( const QString &textChanged ) {
void ContactEditor::slotChooser4Change( const QString &textChanged ) {
- owarn << "ContactEditor::slotChooser4Change( " << textChanged << " )" << oendl;
+ odebug << "ContactEditor::slotChooser4Change( " << textChanged << " )" << oendl;
chooserChange( textChanged, cmbChooserField4->currentItem(), txtChooserField4, 4);
@@ -954,3 +954,3 @@ void ContactEditor::slotCountryChange( const QString &textChanged ) {
void ContactEditor::slotCmbChooser1Change( int index ) {
- owarn << "ContactEditor::slotCmbChooser1Change( " << index << " )" << oendl;
+ odebug << "ContactEditor::slotCmbChooser1Change( " << index << " )" << oendl;
if ( !cmbChooserChange( cmbChooserField1->currentItem(), m_widgetStack1, 1) ){
@@ -965,3 +965,3 @@ void ContactEditor::slotCmbChooser1Change( int index ) {
void ContactEditor::slotCmbChooser2Change( int index ) {
- owarn << "ContactEditor::slotCmbChooser2Change( " << index << " )" << oendl;
+ odebug << "ContactEditor::slotCmbChooser2Change( " << index << " )" << oendl;
@@ -976,3 +976,3 @@ void ContactEditor::slotCmbChooser2Change( int index ) {
void ContactEditor::slotCmbChooser3Change( int index ) {
- owarn << "ContactEditor::slotCmbChooser3Change( " << index << " )" << oendl;
+ odebug << "ContactEditor::slotCmbChooser3Change( " << index << " )" << oendl;
@@ -987,3 +987,3 @@ void ContactEditor::slotCmbChooser3Change( int index ) {
void ContactEditor::slotCmbChooser4Change( int index ) {
- owarn << "ContactEditor::slotCmbChooser4Change( " << index << " )" << oendl;
+ odebug << "ContactEditor::slotCmbChooser4Change( " << index << " )" << oendl;
@@ -1032,3 +1032,3 @@ void ContactEditor::slotFullNameChange( const QString &textChanged ) {
- owarn << "ContactEditor::slotFullNameChange( " << textChanged << " )" << oendl;
+ odebug << "ContactEditor::slotFullNameChange( " << textChanged << " )" << oendl;
@@ -1056,3 +1056,3 @@ void ContactEditor::slotSuffixChange( const QString& ) {
void ContactEditor::slotOrganizationChange( const QString &textChanged ){
- owarn << "ContactEditor::slotOrganizationChange( " << textChanged << " )" << oendl;
+ odebug << "ContactEditor::slotOrganizationChange( " << textChanged << " )" << oendl;
// Special handling for storing Companies:
@@ -1138,3 +1138,3 @@ QString ContactEditor::parseName( const QString fullName, int type ) {
- owarn << "Fullname: " << simplifiedName << oendl;
+ odebug << "Fullname: " << simplifiedName << oendl;
@@ -1142,3 +1142,3 @@ QString ContactEditor::parseName( const QString fullName, int type ) {
if ( commapos >= 0 ) {
- owarn << " Commapos: " << commapos << oendl;
+ odebug << " Commapos: " << commapos << oendl;
@@ -1151,3 +1151,3 @@ QString ContactEditor::parseName( const QString fullName, int type ) {
haveLastName = true;
- owarn << "Fullname without ',': " << simplifiedName << oendl;
+ odebug << "Fullname without ',': " << simplifiedName << oendl;
@@ -1185,6 +1185,6 @@ QString ContactEditor::parseName( const QString fullName, int type ) {
- owarn << "strFirstName: " << strFirstName << oendl;
- owarn << "strMiddletName: " << strMiddleName << oendl;
- owarn << "strLastName: " << strLastName << oendl;
- owarn << "strTitle: " << strTitle << oendl;
+ odebug << "strFirstName: " << strFirstName << oendl;
+ odebug << "strMiddletName: " << strMiddleName << oendl;
+ odebug << "strLastName: " << strLastName << oendl;
+ odebug << "strTitle: " << strTitle << oendl;
@@ -1331,3 +1331,3 @@ void ContactEditor::setEntry( const Opie::OPimContact &entry ) {
- owarn << " Filling dynamic Field: " << (*it) << oendl;
+ odebug << " Filling dynamic Field: " << (*it) << oendl;
@@ -1355,3 +1355,3 @@ void ContactEditor::setEntry( const Opie::OPimContact &entry ) {
if ( *it == "Nickname" ){
- owarn << "**** Nichname: " << ent.nickname() << oendl;
+ odebug << "**** Nichname: " << ent.nickname() << oendl;
(*itLE)->setText( ent.nickname() );
@@ -1588,4 +1588,4 @@ void ContactEditor::saveEntry() {
if ( defaultEmail.isEmpty() ){
- owarn << "Default email was not set by user!" << oendl;
- owarn << "Using first email in list: " << defaultmail << oendl;
+ odebug << "Default email was not set by user!" << oendl;
+ odebug << "Using first email in list: " << defaultmail << oendl;
ent.setDefaultEmail( defaultmail );
@@ -1741,3 +1741,3 @@ void ContactEditor::slotRemoveBirthday()
{
- owarn << "void ContactEditor::slotRemoveBirthday()" << oendl;
+ odebug << "void ContactEditor::slotRemoveBirthday()" << oendl;
ent.setBirthday( QDate() );
@@ -1748,3 +1748,3 @@ void ContactEditor::slotRemoveAnniversary()
{
- owarn << "void ContactEditor::slotRemoveAnniversary()" << oendl;
+ odebug << "void ContactEditor::slotRemoveAnniversary()" << oendl;
ent.setAnniversary( QDate() );
diff --git a/core/pim/addressbook/picker.cpp b/core/pim/addressbook/picker.cpp
index 8a9c85b..b962896 100644
--- a/core/pim/addressbook/picker.cpp
+++ b/core/pim/addressbook/picker.cpp
@@ -241,3 +241,3 @@ void LetterPicker::newLetter( char letter )
{
- owarn << "LetterClicked" << oendl;
+ odebug << "LetterClicked" << oendl;
emit letterClicked( letter );
diff --git a/core/pim/addressbook/abtable.cpp b/core/pim/addressbook/abtable.cpp
index 3fb2214..30d749c 100644
--- a/core/pim/addressbook/abtable.cpp
+++ b/core/pim/addressbook/abtable.cpp
@@ -123,3 +123,3 @@ AbTable::AbTable( const QValueList<int> order, QWidget *parent, const char *name
{
- // owarn << "C'tor start" << oendl;
+ // odebug << "C'tor start" << oendl;
setSelectionMode( NoSelection );
@@ -131,3 +131,3 @@ AbTable::AbTable( const QValueList<int> order, QWidget *parent, const char *name
// contactList.clear();
- // owarn << "C'tor end" << oendl;
+ // odebug << "C'tor end" << oendl;
}
@@ -153,3 +153,3 @@ void AbTable::setContacts( const Opie::OPimContactAccess::List& viewList )
{
- owarn << "AbTable::setContacts()" << oendl;
+ odebug << "AbTable::setContacts()" << oendl;
@@ -185,3 +185,3 @@ bool AbTable::selectContact( int UID )
{
- owarn << "AbTable::selectContact( " << UID << " )" << oendl;
+ odebug << "AbTable::selectContact( " << UID << " )" << oendl;
int rows = numRows();
@@ -191,3 +191,3 @@ bool AbTable::selectContact( int UID )
setPaintingEnabled( FALSE );
- owarn << "Search start" << oendl;
+ odebug << "Search start" << oendl;
for ( int r = 0; r < rows; ++r ) {
@@ -200,3 +200,3 @@ bool AbTable::selectContact( int UID )
}
- owarn << "Search end" << oendl;
+ odebug << "Search end" << oendl;
@@ -215,3 +215,3 @@ void AbTable::insertIntoTable( const Opie::OPimContact& cnt, int row )
{
- owarn << "void AbTable::insertIntoTable( const Opie::OPimContact& cnt, "
+ odebug << "void AbTable::insertIntoTable( const Opie::OPimContact& cnt, "
<< row << " )" << oendl;
@@ -285,3 +285,3 @@ void AbTable::clear()
{
- owarn << "void AbTable::clear()" << oendl;
+ odebug << "void AbTable::clear()" << oendl;
// contactList.clear();
@@ -336,3 +336,3 @@ void AbTable::keyPressEvent( QKeyEvent *e )
- // owarn << "Received key .." << oendl;
+ // odebug << "Received key .." << oendl;
switch( e->key() ) {
@@ -344,3 +344,3 @@ void AbTable::keyPressEvent( QKeyEvent *e )
// case Qt::Key_Up:
-// owarn << "a" << oendl;
+// odebug << "a" << oendl;
// emit signalKeyUp();
@@ -348,3 +348,3 @@ void AbTable::keyPressEvent( QKeyEvent *e )
// case Qt::Key_Down:
-// owarn << "b" << oendl;
+// odebug << "b" << oendl;
// emit signalKeyDown();
@@ -359,3 +359,3 @@ void AbTable::moveTo( char c )
{
- owarn << "void AbTable::moveTo( char c ) NOT IMPLEMENTED !!" << oendl;
+ odebug << "void AbTable::moveTo( char c ) NOT IMPLEMENTED !!" << oendl;
@@ -425,3 +425,3 @@ void AbTable::realignTable()
{
- // owarn << "void AbTable::realignTable()" << oendl;
+ // odebug << "void AbTable::realignTable()" << oendl;
@@ -475,3 +475,3 @@ void AbTable::fitColumns()
{
- owarn << "void AbTable::fitColumns()" << oendl;
+ odebug << "void AbTable::fitColumns()" << oendl;
int contentsWidth = visibleWidth() / 2;
@@ -487,3 +487,3 @@ void AbTable::fitColumns()
- // owarn << "Width: " << contentsWidth << oendl;
+ // odebug << "Width: " << contentsWidth << oendl;
@@ -499,3 +499,3 @@ void AbTable::show()
{
- // owarn << "void AbTable::show()" << oendl;
+ // odebug << "void AbTable::show()" << oendl;
realignTable();
@@ -523,3 +523,3 @@ void AbTable::itemClicked(int,int col)
{
- // owarn << "AbTable::itemClicked(int, col: " << col << ")" << oendl;
+ // odebug << "AbTable::itemClicked(int, col: " << col << ")" << oendl;
if ( col == 2 ) {
@@ -527,3 +527,3 @@ void AbTable::itemClicked(int,int col)
} else {
- // owarn << "Emitting signalSwitch()" << oendl;
+ // odebug << "Emitting signalSwitch()" << oendl;
emit signalSwitch();
@@ -564,3 +564,3 @@ void AbTable::updateVisible()
{
- // owarn << "void AbTable::updateVisible()" << oendl;
+ // odebug << "void AbTable::updateVisible()" << oendl;
@@ -600,3 +600,3 @@ void AbTable::setPaintingEnabled( bool e )
{
// owarn << "IN void AbTable::setPaintingEnabled( " << e << " )->Nested: "
// << countNested << oendl;
@@ -617,3 +617,3 @@ void AbTable::setPaintingEnabled( bool e )
}
// owarn << "OUT void AbTable::setPaintingEnabled( " << e << " )->Nested: "
// << countNested << oendl;
@@ -622,3 +622,3 @@ void AbTable::setPaintingEnabled( bool e )
void AbTable::viewportPaintEvent( QPaintEvent* e ) {
- // owarn << "void AbTable::viewportPaintEvent( QPaintEvent* e ) -> "
+ // odebug << "void AbTable::viewportPaintEvent( QPaintEvent* e ) -> "
// << enablePainting << oendl;
@@ -633,3 +633,3 @@ void AbTable::paintCell(QPainter* p, int row, int col, const QRect& cr, bool )
- // owarn << "Paint row: " << row << oendl;
+ // odebug << "Paint row: " << row << oendl;
@@ -600,3 +600,3 @@ void AbTable::setPaintingEnabled( bool e )
{
- // owarn << "IN void AbTable::setPaintingEnabled( " << e << " )->Nested: "
+ // odebug << "IN void AbTable::setPaintingEnabled( " << e << " )->Nested: "
// << countNested << oendl;
@@ -617,3 +617,3 @@ void AbTable::setPaintingEnabled( bool e )
}
- // owarn << "OUT void AbTable::setPaintingEnabled( " << e << " )->Nested: "
+ // odebug << "OUT void AbTable::setPaintingEnabled( " << e << " )->Nested: "
// << countNested << oendl;
diff --git a/core/pim/addressbook/abview.cpp b/core/pim/addressbook/abview.cpp
index 7a5b6d4..7abb45c 100644
--- a/core/pim/addressbook/abview.cpp
+++ b/core/pim/addressbook/abview.cpp
@@ -54,3 +54,3 @@ AbView::AbView ( QWidget* parent, const QValueList<int>& ordered ):
{
- owarn << "AbView::c'tor" << oendl;
+ odebug << "AbView::c'tor" << oendl;
// Load default database and handle syncing myself.. !
@@ -102,3 +102,3 @@ void AbView::setView( Views view )
{
- owarn << "AbView::setView( Views view )" << oendl;
+ odebug << "AbView::setView( Views view )" << oendl;
m_curr_View = view;
@@ -109,3 +109,3 @@ void AbView::addEntry( const Opie::OPimContact &newContact )
{
- owarn << "AbView::AddContact" << oendl;
+ odebug << "AbView::AddContact" << oendl;
m_contactdb->add ( newContact );
@@ -116,3 +116,3 @@ void AbView::removeEntry( const int UID )
{
- owarn << "AbView;:RemoveContact" << oendl;
+ odebug << "AbView;:RemoveContact" << oendl;
m_contactdb->remove( UID );
@@ -123,3 +123,3 @@ void AbView::replaceEntry( const Opie::OPimContact &contact )
{
- owarn << "AbView::ReplaceContact" << oendl;
+ odebug << "AbView::ReplaceContact" << oendl;
m_contactdb->replace( contact );
@@ -147,3 +147,3 @@ bool AbView::save()
{
- // owarn << "AbView::Save data" << oendl;
+ // odebug << "AbView::Save data" << oendl;
@@ -154,3 +154,3 @@ void AbView::load()
{
- owarn << "AbView::Load data" << oendl;
+ odebug << "AbView::Load data" << oendl;
@@ -168,3 +168,3 @@ void AbView::load()
- owarn << "Number of contacts: " << m_list.count() << oendl;
+ odebug << "Number of contacts: " << m_list.count() << oendl;
@@ -176,3 +176,3 @@ void AbView::reload()
{
- owarn << "AbView::::reload()" << oendl;
+ odebug << "AbView::::reload()" << oendl;
@@ -189,3 +189,3 @@ void AbView::setShowByCategory( const QString& cat )
{
- owarn << "AbView::setShowCategory( const QString& cat )" << oendl;
+ odebug << "AbView::setShowCategory( const QString& cat )" << oendl;
@@ -201,3 +201,3 @@ void AbView::setShowByCategory( const QString& cat )
if ( intCat != m_curr_category ){
// owarn << "Categories: Selected " << cat << ".. Number: "
// << m_curr_category << oendl;
@@ -214,6 +214,6 @@ void AbView::setShowToView( Views view )
{
- owarn << "void AbView::setShowToView( View " << view << " )" << oendl;
+ odebug << "void AbView::setShowToView( View " << view << " )" << oendl;
if ( m_curr_View != view ){
- owarn << "Change the View (Category is: " << m_curr_category << ")" << oendl;
+ odebug << "Change the View (Category is: " << m_curr_category << ")" << oendl;
m_prev_View = m_curr_View;
@@ -228,3 +228,3 @@ void AbView::setShowByLetter( char c, AbConfig::LPSearchMode mode )
{
- owarn << "void AbView::setShowByLetter( " << c << ", " << mode << " )" << oendl;
+ odebug << "void AbView::setShowByLetter( " << c << ", " << mode << " )" << oendl;
@@ -281,3 +281,3 @@ void AbView::showPersonal( bool personal )
{
- owarn << "void AbView::showPersonal( " << personal << " )" << oendl;
+ odebug << "void AbView::showPersonal( " << personal << " )" << oendl;
@@ -351,3 +351,3 @@ void AbView::slotDoFind( const QString &str, bool caseSensitive, bool useRegExp,
- // owarn << "Find in Category " << category << oendl;
+ // odebug << "Find in Category " << category << oendl;
@@ -360,3 +360,3 @@ void AbView::slotDoFind( const QString &str, bool caseSensitive, bool useRegExp,
- // owarn << "Found: " << m_list.count() << oendl;
+ // odebug << "Found: " << m_list.count() << oendl;
if ( m_list.count() == 0 ){
@@ -384,3 +384,3 @@ void AbView::offSearch()
void AbView::slotSwitch(){
- // owarn << "AbView::slotSwitch()" << oendl;
+ // odebug << "AbView::slotSwitch()" << oendl;
@@ -389,3 +389,3 @@ void AbView::slotSwitch(){
case TableView:
- owarn << "Switching to CardView" << oendl;
+ odebug << "Switching to CardView" << oendl;
m_curr_View = CardView;
@@ -393,3 +393,3 @@ void AbView::slotSwitch(){
case CardView:
- owarn << "Switching to TableView" << oendl;
+ odebug << "Switching to TableView" << oendl;
m_curr_View = TableView;
@@ -412,3 +412,3 @@ void AbView::clearForCategory()
if ( !contactCompare( *it, m_curr_category ) ){
- //owarn << "Removing " << (*it).uid() << oendl;
+ //odebug << "Removing " << (*it).uid() << oendl;
m_list.remove( (*it).uid() );
@@ -422,3 +422,3 @@ bool AbView::contactCompare( const Opie::OPimContact &cnt, int category )
{
// owarn << "bool AbView::contactCompare( const Opie::OPimContact &cnt, "
// << category << " )" << oendl;
@@ -429,3 +429,3 @@ bool AbView::contactCompare( const Opie::OPimContact &cnt, int category )
- // owarn << "Number of categories: " << cats.count() << oendl;
+ // odebug << "Number of categories: " << cats.count() << oendl;
@@ -438,3 +438,3 @@ bool AbView::contactCompare( const Opie::OPimContact &cnt, int category )
for ( i = 0; i < int(cats.count()); i++ ) {
- //owarn << "Comparing " << cats[i] << " with " << category << oendl;
+ //odebug << "Comparing " << cats[i] << " with " << category << oendl;
if ( cats[i] == category ) {
@@ -445,3 +445,3 @@ bool AbView::contactCompare( const Opie::OPimContact &cnt, int category )
}
- // owarn << "Return: " << returnMe << oendl;
+ // odebug << "Return: " << returnMe << oendl;
return returnMe;
@@ -458,3 +458,3 @@ void AbView::updateView( bool newdata )
{
- // owarn << "AbView::updateView()" << oendl;
+ // odebug << "AbView::updateView()" << oendl;
@@ -201,3 +201,3 @@ void AbView::setShowByCategory( const QString& cat )
if ( intCat != m_curr_category ){
- // owarn << "Categories: Selected " << cat << ".. Number: "
+ // odebug << "Categories: Selected " << cat << ".. Number: "
// << m_curr_category << oendl;
@@ -422,3 +422,3 @@ bool AbView::contactCompare( const Opie::OPimContact &cnt, int category )
{
- // owarn << "bool AbView::contactCompare( const Opie::OPimContact &cnt, "
+ // odebug << "bool AbView::contactCompare( const Opie::OPimContact &cnt, "
// << category << " )" << oendl;